:py:mod:`random_number_generator_worker`
========================================

.. py:module:: random_number_generator_worker


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   random_number_generator_worker.initialise
   random_number_generator_worker.create_evaluation_string
   random_number_generator_worker.random_number
   random_number_generator_worker.on_end_of_life



Attributes
~~~~~~~~~~

.. autoapisummary::

   random_number_generator_worker.current_dir
   random_number_generator_worker.current_dir
   random_number_generator_worker.vis
   random_number_generator_worker.worker_object


.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: vis
   :annotation: :Heron.gui.visualisation_dpg.VisualisationDPG

   

.. py:function:: initialise(worker_object)


.. py:function:: create_evaluation_string(parameters)


.. py:function:: random_number(data, parameters)


.. py:function:: on_end_of_life()


.. py:data:: worker_object
   

   

